exec_or_wait_for_shutdown

Function exec_or_wait_for_shutdown 

pub async fn exec_or_wait_for_shutdown(
    exec: Option<Vec<OsString>>,
    task_group: &TaskGroup,
) -> Result<()>
Runs the user command if there is one, otherwise waits for the task group to be told to shut down, e.g. by a signal.